import Crypto from "crypto";
import { ObjectUtils } from "../implementations/ObjectUtils.js";
export class TimedCache {
    constructor(cacheTimeSeconds, timeUtils) {
        this.cacheTimeSeconds = cacheTimeSeconds;
        this.timeUtils = timeUtils;
        this.cache = new Map();
    }
    get(...args) {
        const key = this.getKey(args);
        const value = this.cache.get(key);
        // No cached value
        if (value == null) {
            return null;
        }
        // Check the timestamp- return null if the entry is expired
        const now = this.timeUtils.getUnixNow();
        if (now - value.timestamp > this.cacheTimeSeconds) {
            return null;
        }
        // Entry is still valid
        return value.value;
    }
    set(value, ...args) {
        const key = this.getKey(args);
        const now = this.timeUtils.getUnixNow();
        this.cache.set(key, new CacheEntry(now, value));
    }
    clearAll() {
        this.cache.clear();
    }
    clear(...args) {
        const key = this.getKey(args);
        this.cache.delete(key);
    }
    getKey(args) {
        const json = ObjectUtils.serialize(args);
        return Crypto.createHash("md5").update(json).digest("base64");
    }
}
class CacheEntry {
    constructor(timestamp, value) {
        this.timestamp = timestamp;
        this.value = value;
    }
}
//# sourceMappingURL=TimedCache.js.map